@@ -1,5 +1,6 @@
 __all__ = ["OpponentSpace", "BaseActionBudget", "BaseOpponent", "UnlimitedBudget",
-           "RandomLineOpponent", "WeightedRandomOpponent", "NeverAttackBudget"]
+           "RandomLineOpponent", "WeightedRandomOpponent", "NeverAttackBudget",
+           "GeometricOpponent"]
 
 from grid2op.Opponent.OpponentSpace import OpponentSpace
 from grid2op.Opponent.BaseActionBudget import BaseActionBudget
@@ -8,3 +9,4 @@ from grid2op.Opponent.UnlimitedBudget import UnlimitedBudget
 from grid2op.Opponent.RandomLineOpponent import RandomLineOpponent
 from grid2op.Opponent.WeightedRandomOpponent import WeightedRandomOpponent
 from grid2op.Opponent.NeverAttackBudget import NeverAttackBudget
+from grid2op.Opponent.GeometricOpponent import GeometricOpponent
