@@ -31,20 +31,18 @@ class PreventReconnection(BaseRules):
         # at first iteration, env.current_obs is None...
         # TODO this is used inside the environment (for step) inside LookParam and here
         # this could be computed only once, and fed to this instead
-        if env.current_obs is not None:
-            powerline_status = env.current_obs.line_status
-        else:
-            powerline_status = None
+        powerline_status = env.get_current_line_status()
+
         aff_lines, aff_subs = action.get_topological_impact(powerline_status)
-        if np.any(env.times_before_line_status_actionable[aff_lines] > 0):
+        if np.any(env._times_before_line_status_actionable[aff_lines] > 0):
             # i tried to act on a powerline too shortly after a previous action
             # or shut down due to an overflow or opponent or hazards or maintenance
-            ids = np.where(env.times_before_line_status_actionable[aff_lines] > 0)[0]
+            ids = np.where((env._times_before_line_status_actionable > 0) & aff_lines)[0]
             return False, IllegalAction("Powerline with ids {} have been modified illegally (cooldown)".format(ids))
 
-        if np.any(env.times_before_topology_actionable[aff_subs] > 0):
+        if np.any(env._times_before_topology_actionable[aff_subs] > 0):
             # I tried to act on a topology too shortly after a previous action
-            ids = np.where(env.times_before_line_status_actionable[aff_lines] > 0)[0]
+            ids = np.where((env._times_before_topology_actionable > 0) & aff_subs)[0]
             return False, IllegalAction("Substation with ids {} have been modified illegally (cooldown)".format(ids))
 
         return True, None
